'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPosts = getPosts;
exports.addPost = addPost;
exports.getPost = getPost;
exports.deletePost = deletePost;

var _model = require('./model');

var _model2 = _interopRequireDefault(_model);

var _cuid = require('cuid');

var _cuid2 = _interopRequireDefault(_cuid);

var _slug = require('slug');

var _slug2 = _interopRequireDefault(_slug);

var _sanitizeHtml = require('sanitize-html');

var _sanitizeHtml2 = _interopRequireDefault(_sanitizeHtml);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getPosts(req, res) {
  _model2.default.find().sort('-dateAdded').exec(function (err, posts) {
    if (err) {
      res.status(500).send(err);
      return;
    }

    res.json({ posts: posts });
  });
}

function addPost(req, res) {
  if (!req.body.post.name || !req.body.post.title || !req.body.post.content) {
    res.status(403).end();
    return;
  }

  var newPost = new _model2.default(req.body.post);

  // Let's sanitize inputs
  newPost.title = (0, _sanitizeHtml2.default)(newPost.title);
  newPost.name = (0, _sanitizeHtml2.default)(newPost.name);
  newPost.content = (0, _sanitizeHtml2.default)(newPost.content);

  newPost.slug = (0, _slug2.default)(newPost.title.toLowerCase(), { lowercase: true });
  newPost.cuid = (0, _cuid2.default)();

  newPost.save(function (err, saved) {
    if (err) {
      res.status(500).send(err);
      return;
    }

    res.json({ post: saved });
    return;
  });
}

function getPost(req, res) {
  var newSlug = req.query.slug.split('-');
  var newCuid = newSlug[newSlug.length - 1];

  _model2.default.findOne({ cuid: newCuid }).exec(function (err, post) {
    if (err) {
      res.status(500).send(err);
      return;
    }

    res.json({ post: post });
  });
}

function deletePost(req, res) {
  var postId = req.body.postId;

  _model2.default.findById(postId).exec(function (err, post) {
    if (err) {
      res.status(500).send(err);
      return;
    }

    post.remove(function () {
      res.status(200).end();
    });
  });
}
//# sourceMappingURL=action.js.map