import { model, route, ROUTE_NAME } from '../../src/modules/user';
import { DATABASE_URL_TEST } from '../../src/config';

import seedData from '../../src/utils/seedData';
import connectDb from '../../src/utils/connectDb';
import dropDb from '../../src/utils/dropDb';

import TestCreator from '../../src/utils/TestCreator';

const MOCK_DATA = [
  { email: 'yhjor@me.com', display_name: 'George Jor' },
  { email: 'yhjor@live.hk', display_name: 'Jorge Jor' },
];

const test = new TestCreator(route, model, ROUTE_NAME, MOCK_DATA);

describe('User Modules', () => {
  before(() => connectDb(DATABASE_URL_TEST));

  beforeEach(() => seedData(model, MOCK_DATA));

  after(() => dropDb());

  it('GET /api/users', done => {
    test.list(done);
  });

  it('GET /api/users/:id', done => {
    test.get(done);
  });

  it('POST /api/users', done => {
    const newUser = {
      email: 'yhjor.me@gmail.com',
      display_name: 'yhjor',
    };

    test.new(newUser, done);
  });

  it('PUT /api/users/:id', done => {
    const updateUser = {
      email: 'yhjor@me.com',
      display_name: 'JOR YU HIN',
    };

    test.update(updateUser, 'email', done);
  });

  it('DELETE /api/users/:id', done => {
    test.delete('email', done);
  });
});
